<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it">
<context>
    <name>CompletingEdit</name>
    <message>
        <source>No suggestions</source>
        <translation>Nessun suggerimento</translation>
    </message>
    <message>
        <source>Jump to PDF</source>
        <translation>Vai al PDF</translation>
    </message>
    <message>
        <source>Ignore word</source>
        <translation>Ignora parola</translation>
    </message>
</context>
<context>
    <name>ConfirmDelete</name>
    <message>
        <source>Delete</source>
        <translation>Cancella</translation>
    </message>
    <message>
        <source>Unable to delete</source>
        <translation>Impossibile cancellare</translation>
    </message>
    <message>
        <source>Some of the auxiliary files could not be removed. Perhaps you don&apos;t have permission to delete them.</source>
        <translation>Qualche file ausiliario non può essere cancellato. Forse non hai sufficienti diritti.</translation>
    </message>
    <message>
        <source>Confirm file deletion</source>
        <translation>Conferma eliminazione file</translation>
    </message>
    <message>
        <source>Auxiliary files to be deleted:</source>
        <translation>File ausiliari da eliminare:</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Seleziona tutto</translation>
    </message>
    <message>
        <source>Select None</source>
        <translation>Seleziona nulla</translation>
    </message>
    <message>
        <source>Toggle</source>
        <translation>Abilita/disabilita</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Find</source>
        <translation>Cerca</translation>
    </message>
    <message>
        <source>Find:</source>
        <translation>Cerca:</translation>
    </message>
    <message>
        <source>&amp;Wrap around</source>
        <translation>Riparti &amp;dall&apos;inizio</translation>
    </message>
    <message>
        <source>Find &amp;backwards</source>
        <translation>Cerca &amp;precedente</translation>
    </message>
    <message>
        <source>Search within &amp;selection</source>
        <translation>Cerca nella &amp;selezione</translation>
    </message>
    <message>
        <source>Find &amp;all occurrences</source>
        <translation>Cerca &amp;tutte le occorrenze</translation>
    </message>
    <message>
        <source>Search all &amp;open files</source>
        <translation>Cerca in tutti i file &amp;aperti</translation>
    </message>
    <message>
        <source>&amp;Case sensitive</source>
        <translation>&amp;Maiuscole/minuscole</translation>
    </message>
    <message>
        <source>W&amp;hole words</source>
        <translation>Parola int&amp;era</translation>
    </message>
    <message>
        <source>&amp;Regular expression</source>
        <translation>Espressione &amp;regolare</translation>
    </message>
    <message>
        <source>(invalid)</source>
        <translation>(invalido)</translation>
    </message>
    <message>
        <source>No recent search strings</source>
        <translation>Nessuna stringa di ricerca recente</translation>
    </message>
</context>
<context>
    <name>HardWrapDialog</name>
    <message>
        <source>Hard Wrap</source>
        <translation>Interruzione linee</translation>
    </message>
    <message>
        <source>Wrap lines to:</source>
        <translation>Interrompi le linee a:</translation>
    </message>
    <message>
        <source>Current window size</source>
        <translation>Dimensione finestra attuale</translation>
    </message>
    <message>
        <source>Line length:</source>
        <translation>Larghezza linea:</translation>
    </message>
    <message>
        <source>Re-wrap paragraphs</source>
        <translation>Ri-formatta paragrafi</translation>
    </message>
    <message>
        <source>Unwrap</source>
        <translation>Rimuovi formattazione</translation>
    </message>
</context>
<context>
    <name>PDFDocument</name>
    <message>
        <source>Open Recent</source>
        <translation>Apri recenti</translation>
    </message>
    <message>
        <source>No SyncTeX data available</source>
        <translation>SyncTeX non disponibile</translation>
    </message>
    <message>
        <source>SyncTeX: &quot;%1&quot;</source>
        <translation>SyncTeX &quot;%1&quot;</translation>
    </message>
    <message>
        <source>%1[*] - %2</source>
        <translation>%1[*] - %2</translation>
    </message>
    <message>
        <source>page %1 of %2</source>
        <translation>pagina %1 de %2</translation>
    </message>
    <message>
        <source>%1%</source>
        <translation>%1%</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Aiuto</translation>
    </message>
    <message>
        <source>File</source>
        <translation>File</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Modifica</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Vista</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Finestra</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>Visualizza</translation>
    </message>
    <message>
        <source>Typeset</source>
        <translation>Typeset</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Strumenti</translation>
    </message>
    <message>
        <source>About TeXworks...</source>
        <translation>A proposito di TeXworks...</translation>
    </message>
    <message>
        <source>First Page</source>
        <translation>Prima pagina</translation>
    </message>
    <message>
        <source>Previous Page</source>
        <translation>Pagina precedente</translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation>Pagina successiva</translation>
    </message>
    <message>
        <source>Last Page</source>
        <translation>Ultima pagina</translation>
    </message>
    <message>
        <source>Go to Page...</source>
        <translation>Vai a pagina...</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <source>Zoom In</source>
        <translation>Zoom +</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation>Zoom -</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation></translation>
    </message>
    <message>
        <source>Fit to Window</source>
        <translation>Adatta alla finestra</translation>
    </message>
    <message>
        <source>Ctrl+3</source>
        <translation></translation>
    </message>
    <message>
        <source>Actual Size</source>
        <translation>Dimensione attuale</translation>
    </message>
    <message>
        <source>Ctrl+1</source>
        <translation></translation>
    </message>
    <message>
        <source>Fit to Width</source>
        <translation>Adatta larghezza</translation>
    </message>
    <message>
        <source>Ctrl+2</source>
        <translation></translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nuovo</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation></translation>
    </message>
    <message>
        <source>Open...</source>
        <translation>Apri...</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation></translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation></translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation></translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Ripeti</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Z</source>
        <translation></translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Taglia</translation>
    </message>
    <message>
        <source>Ctrl+X</source>
        <translation></translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <source>Ctrl+C</source>
        <translation></translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Incolla</translation>
    </message>
    <message>
        <source>Ctrl+V</source>
        <translation></translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Pulisci</translation>
    </message>
    <message>
        <source>Ctrl+Backspace</source>
        <translation></translation>
    </message>
    <message>
        <source>Preferences...</source>
        <translation>Preferenze...</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Cascata</translation>
    </message>
    <message>
        <source>Tile</source>
        <translation>Mosaico</translation>
    </message>
    <message>
        <source>Go to Source</source>
        <translation>Vai al sorgente</translation>
    </message>
    <message>
        <source>Ctrl+&apos;</source>
        <translation></translation>
    </message>
    <message>
        <source>New from Template...</source>
        <translation>Nuovo da modello...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation></translation>
    </message>
    <message>
        <source>Full Screen</source>
        <translation>Schermo intero</translation>
    </message>
    <message>
        <source>Ctrl+Shift+F</source>
        <translation></translation>
    </message>
    <message>
        <source>Magnify</source>
        <translation>Ingrandisci</translation>
    </message>
    <message>
        <source>Scroll</source>
        <translation>Scroll</translation>
    </message>
    <message>
        <source>Select Text</source>
        <translation>Seleziona testo</translation>
    </message>
    <message>
        <source>Select Image</source>
        <translation>Seleziona immagine</translation>
    </message>
    <message>
        <source>Go to TeXworks home page</source>
        <translation>Vai alla home page di Texworks</translation>
    </message>
    <message>
        <source>Email to the mailing list</source>
        <translation>Scrivi alla mailing list</translation>
    </message>
    <message>
        <source>Side by Side</source>
        <translation>Affiancate</translation>
    </message>
    <message>
        <source>Place on Left</source>
        <translation>Posizione a sinistra</translation>
    </message>
    <message>
        <source>Place on Right</source>
        <translation>Posizione a destra</translation>
    </message>
    <message>
        <source>Failed to load file &quot;%1&quot;; perhaps it is not a valid PDF document.</source>
        <translation>Apertura di &quot;%1&quot;; forse non è un documento PDF valido.</translation>
    </message>
    <message>
        <source>untitled.pdf[*]</source>
        <translation>senza_nome.pdf[*]</translation>
    </message>
    <message>
        <source>Ctrl+PgUp</source>
        <comment>shortcut key name, do not translate</comment>
        <translation>Ctrl+PgUp</translation>
    </message>
    <message>
        <source>Ctrl+PgDown</source>
        <comment>shortcut key name, do not translate</comment>
        <translation>Ctrl+PgDown</translation>
    </message>
    <message>
        <source>Quit TeXworks</source>
        <translation>Chiudi TeXworks</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation></translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Find Again</source>
        <translation>Cerca successivo</translation>
    </message>
    <message>
        <source>Find...</source>
        <translation>Cerca...</translation>
    </message>
    <message>
        <source>Typeset</source>
        <comment>menu title</comment>
        <translation>Composizione</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <comment>action</comment>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>Script</translation>
    </message>
    <message>
        <source>Scripting TeXworks</source>
        <translation>TeXworks scripting</translation>
    </message>
    <message>
        <source>Reload Script List</source>
        <translation>Ricarica lista script</translation>
    </message>
    <message>
        <source>Manage Scripts</source>
        <translation>Gestisci script</translation>
    </message>
    <message>
        <source>Show Scripts Folder</source>
        <translation>Mostra cartella script</translation>
    </message>
    <message>
        <source>About Scripts...</source>
        <translation>A proposito degli script...</translation>
    </message>
    <message>
        <source>Print Pdf...</source>
        <translation>Stampa Pdf...</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>Abort typesetting</source>
        <translation>Interrompi typesetting</translation>
    </message>
    <message>
        <source>Unfortunately, this version of %1 is unable to print Pdf documents due to various technical reasons.
</source>
        <translation>Purtroppo questa versione di %1 non è in grado di stampare documenti Pdf per motivi tecnici.</translation>
    </message>
    <message>
        <source>Do you want to open the file in the default viewer for printing instead?</source>
        <translation>Vuoi aprire il file nel visualizzatore di default?</translation>
    </message>
    <message>
        <source> (remember to close it again to avoid access problems)</source>
        <translation> (ricorda di chiuderlo di nuovo per evitare problemi di accesso)</translation>
    </message>
    <message>
        <source>Settings and Resources...</source>
        <translation>Preferenze e Risorse...</translation>
    </message>
    <message>
        <source>Clear Recent Files</source>
        <translation>Elimina file recenti</translation>
    </message>
    <message>
        <source>Error initializing SyncTeX</source>
        <translation>Errore nell&apos;inizializzazione di SyncTeX</translation>
    </message>
    <message>
        <source>Go to previous view</source>
        <translation>Vai alla vista precedente</translation>
    </message>
    <message>
        <source>Alt+Left</source>
        <translation>Alt+sinistra</translation>
    </message>
    <message>
        <source>Single Page</source>
        <translation>Pagina singola</translation>
    </message>
    <message>
        <source>Single Page Continuous</source>
        <translation>Pagina singola continua</translation>
    </message>
    <message>
        <source>Two Pages Continuous</source>
        <translation>Due pagine continue</translation>
    </message>
    <message>
        <source>Jump to Source</source>
        <translation>Vai al sorgente</translation>
    </message>
    <message>
        <source>Go to Page</source>
        <translation>Vai a pagina</translation>
    </message>
    <message>
        <source>Page number:</source>
        <translation>Pagina numero:</translation>
    </message>
    <message>
        <source>Open URL</source>
        <translation>Apri URL</translation>
    </message>
    <message>
        <source>You are in the process of opening the URL %1. Opening unknown or untrusted web adresses can be a security risk.
Do you want to continue?</source>
        <translation>Stai per aprire l&apos;URL %1. L&apos;apertura di indirizzi web sconosciuti o non verificati comporta rischi per la sicurezza.
Vuoi continuare?</translation>
    </message>
    <message>
        <source>Custom...</source>
        <translation>Persolnalizza...</translation>
    </message>
    <message>
        <source>Set Zoom</source>
        <translation>Imposta zoom</translation>
    </message>
    <message>
        <source>Zoom level:</source>
        <translation>Livello di zoom</translation>
    </message>
</context>
<context>
    <name>PDFFindDialog</name>
    <message>
        <source>Find</source>
        <translation>Cerca</translation>
    </message>
    <message>
        <source>No recent search strings</source>
        <translation>Nessuna ricerca recente</translation>
    </message>
    <message>
        <source>Find in PDF</source>
        <translation>Cerca nel PDF</translation>
    </message>
    <message>
        <source>Find:</source>
        <translation>Cerca:</translation>
    </message>
    <message>
        <source>&amp;Wrap around</source>
        <translation>Riparti &amp;dall&apos;inizio</translation>
    </message>
    <message>
        <source>Find &amp;backwards</source>
        <translation>Cerca  &amp;precedente</translation>
    </message>
    <message>
        <source>Find &amp;all occurrences</source>
        <translation>Cerca &amp;tutte le occorrenze</translation>
    </message>
    <message>
        <source>&amp;Case sensitive</source>
        <translation>&amp;Maiuscole/minuscole</translation>
    </message>
    <message>
        <source>&amp;Sync to source</source>
        <translation>&amp;Sincronizza con la sorgente</translation>
    </message>
</context>
<context>
    <name>PrefsDialog</name>
    <message>
        <source>Choose Directory</source>
        <translation>Seleziona una directory</translation>
    </message>
    <message>
        <source>New Tool</source>
        <translation>Nuovo strumento</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nessuno</translation>
    </message>
    <message>
        <source>TeXworks Preferences</source>
        <translation>Preferenze TeXworks</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <source>Small icons</source>
        <translation>Icone piccole</translation>
    </message>
    <message>
        <source>Medium icons</source>
        <translation>Icone medie</translation>
    </message>
    <message>
        <source>Large icons</source>
        <translation>Icone grandi</translation>
    </message>
    <message>
        <source>Show text as well as icons</source>
        <translation>Mostra testo et icona</translation>
    </message>
    <message>
        <source>When launched, show</source>
        <translation>All&apos;avvio, mostra</translation>
    </message>
    <message>
        <source>New blank document</source>
        <translation>Nuovo documento vuoto</translation>
    </message>
    <message>
        <source>Template selection dialog</source>
        <translation>Dialogo selezione modello</translation>
    </message>
    <message>
        <source>File Open dialog</source>
        <translation>Dialogo apri file</translation>
    </message>
    <message>
        <source>Editor</source>
        <translation>Editor</translation>
    </message>
    <message>
        <source>Editor defaults</source>
        <translation>Parametri di default dell&apos;editor</translation>
    </message>
    <message>
        <source> pt</source>
        <translation>pt</translation>
    </message>
    <message>
        <source>Tab width:</source>
        <translation>Larghezza tabulazione:</translation>
    </message>
    <message>
        <source>Wrap lines</source>
        <translation>A capo automatico</translation>
    </message>
    <message>
        <source>Syntax coloring:</source>
        <translation>Colorazione sintassi:</translation>
    </message>
    <message>
        <source>Auto-Indent mode:</source>
        <translation>Modalità rientro automatico:</translation>
    </message>
    <message>
        <source>Spell-check language:</source>
        <translation>Lingua verifica ortografia:</translation>
    </message>
    <message>
        <source>Encoding:</source>
        <translation>Encoding:</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation>Anteprima</translation>
    </message>
    <message>
        <source>Default scaling</source>
        <translation>Ridimensionamento di default</translation>
    </message>
    <message>
        <source>Actual size</source>
        <translation>Dimensione attuale</translation>
    </message>
    <message>
        <source>Fit to Width</source>
        <translation>Adatta larghezza</translation>
    </message>
    <message>
        <source>Fit to Window</source>
        <translation>Adatta alla finestra</translation>
    </message>
    <message>
        <source>Fixed scale:</source>
        <translation>Dimensione fissa:</translation>
    </message>
    <message>
        <source> %</source>
        <translation>%</translation>
    </message>
    <message>
        <source>Magnifying glass</source>
        <translation>Lente</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Piccola</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Media</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Grande</translation>
    </message>
    <message>
        <source>Circular magnifier</source>
        <translation>Lente circolare</translation>
    </message>
    <message>
        <source>Screen resolution:</source>
        <translation>Risoluzione schermo:</translation>
    </message>
    <message>
        <source> dpi</source>
        <translation type="obsolete"> dpi (punti pp)</translation>
    </message>
    <message>
        <source>Typesetting</source>
        <translation>Composizione</translation>
    </message>
    <message>
        <source>Paths for TeX and related programs</source>
        <translation>Percorso di Tex e relativi programmi</translation>
    </message>
    <message>
        <source>Processing tools</source>
        <translation>Strumenti di processo</translation>
    </message>
    <message>
        <source>Edit...</source>
        <translation>Modifica...</translation>
    </message>
    <message>
        <source>Default:</source>
        <translation>Default:</translation>
    </message>
    <message>
        <source>System default [%1]</source>
        <translation>Sistema di default [%1]</translation>
    </message>
    <message>
        <source>Line numbers</source>
        <translation>Numeri di linea</translation>
    </message>
    <message>
        <source>Global editor options</source>
        <translation>Preferenze globali editor</translation>
    </message>
    <message>
        <source>Highlight current line</source>
        <translation>Evidenzia linea corrente</translation>
    </message>
    <message>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <source>Smart Quotes mode:</source>
        <translatorcomment>Chi ha una traduzione migliore?</translatorcomment>
        <translation>Modo virgolette:</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>Script</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Sicurezza</translation>
    </message>
    <message>
        <source>Allow scripts to read all files (script and document files are always readable)</source>
        <translation>Consenti agli script di leggere ogni file (i file di script e documenti sono già sempre leggibili)</translation>
    </message>
    <message>
        <source>Allow scripts to write files</source>
        <translation>Permetti agli script di scrivere i file</translation>
    </message>
    <message>
        <source>Allow scripts to run system commands</source>
        <translation>Permetti agli script di lanciare comandi di sistema</translation>
    </message>
    <message>
        <source>Enable plug-in scripting languages (may circumvent other restrictions on script behavior)</source>
        <translation>Abilita plug-in linguaggi di scripting (potrebbe superare alcune restrizioni nel comportamento degli script)</translation>
    </message>
    <message>
        <source>Debugging</source>
        <translation>Debugging</translation>
    </message>
    <message>
        <source>Enable QtScript debugger</source>
        <translation>Abilita il debugger QtScript</translation>
    </message>
    <message>
        <source>Never</source>
        <extracomment>&quot;Hide console output&quot; mode</extracomment>
        <translation>Mai</translation>
    </message>
    <message>
        <source>Automatically</source>
        <extracomment>&quot;Hide console output&quot; mode</extracomment>
        <translation>Automaticamente</translation>
    </message>
    <message>
        <source>On success</source>
        <extracomment>&quot;Hide console output&quot; mode</extracomment>
        <translation>In caso di successo</translation>
    </message>
    <message>
        <source>&lt;em&gt;Note:&lt;/em&gt; These are default settings. Changes to them will not affect windows that are already open. Use the respective items in the &amp;quot;Format&amp;quot; menu to achieve that.</source>
        <translation>&lt;em&gt;Nota:&lt;/em&gt; Questi sono i settaggi di default. Eventuali cambi non avranno effetto sulle finestre già aperte. Per ottenere questo risultato usa le corrispondenti opzioni del menù &amp;quot;Formato&amp;quot;.</translation>
    </message>
    <message>
        <source>Enable autocompletion</source>
        <translation>Abilita autocompletamento</translation>
    </message>
    <message>
        <source>Hide console output:</source>
        <translation>Nascondi output console:</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;strong&gt;Never:&lt;/strong&gt; Never hide the console output panel after typesetting.&lt;/p&gt;
&lt;p&gt;&lt;strong&gt;Automatically:&lt;/strong&gt; Hide the console output panel after successful typesetting, but only if it was hidden before.&lt;/p&gt;
&lt;p&gt;&lt;strong&gt;On Success:&lt;/strong&gt; Hide the console output panel after successful typesetting, regardless of its previous state.&lt;/p&gt;
</source>
        <translation>&lt;p&gt;&lt;strong&gt;Mai:&lt;/strong&gt; Non nascondere mai il pannello di output dopo la composizione.&lt;/p&gt;
&lt;p&gt;&lt;strong&gt;Automaticamente:&lt;/strong&gt; Nascondi il pannello di output dopo l&apos;esito positivo della composizione  solo se era già nascosto prima.&lt;/p&gt;
&lt;p&gt;&lt;strong&gt;Esito positivo:&lt;/strong&gt; Nascondi il pannello di output dopo l&apos;esito positivo della composizione.&lt;/p&gt;
</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Interfaccia</translation>
    </message>
    <message>
        <source>Locale:</source>
        <translation>Locale:</translation>
    </message>
    <message>
        <source>Toolbar buttons:</source>
        <translation>Pulsanti barra strumenti:</translation>
    </message>
    <message>
        <source>Open corresponding PDF preview with TeX files</source>
        <translation>Apri l&apos;anteprima del PDF corrispondente con i file TeX</translation>
    </message>
    <message>
        <source>Page mode:</source>
        <translation>Modalità pagina</translation>
    </message>
    <message>
        <source>Single Page</source>
        <translation>Pagina singola</translation>
    </message>
    <message>
        <source>Single Page Continuous</source>
        <translation>Pagina singola continua</translation>
    </message>
    <message>
        <source>Two Page Continuous</source>
        <translation>Due pagine continue</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>TeX documents (*.tex)</source>
        <translation>Documenti TeX (*.tex)</translation>
    </message>
    <message>
        <source>LaTeX documents (*.ltx)</source>
        <translation>Documenti LaTeX (*.ltx)</translation>
    </message>
    <message>
        <source>BibTeX databases (*.bib)</source>
        <translation>Database BibTeX (*.bib)</translation>
    </message>
    <message>
        <source>Style files (*.sty)</source>
        <translation>File di stile (*.sty)</translation>
    </message>
    <message>
        <source>Class files (*.cls)</source>
        <translation>File di classe (*.cls)</translation>
    </message>
    <message>
        <source>Documented macros (*.dtx)</source>
        <translation>Macro documentate (*.dtx)</translation>
    </message>
    <message>
        <source>Text files (*.txt)</source>
        <translation>File di testo (*.txt)</translation>
    </message>
    <message>
        <source>PDF documents (*.pdf)</source>
        <translation>Documenti PDF (*.pdf)</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Tutti i file</translation>
    </message>
    <message>
        <source>Log files (*.log *.blg)</source>
        <translation>File di log (*.log *.blg)</translation>
    </message>
    <message>
        <source>Auxiliary files (*.aux *.toc *.lot *.lof *.nav *.out *.snm *.ind *.idx *.bbl *.brf)</source>
        <translation>File ausiliari (*.aux *.toc *.lot *.lof *.nav *.out *.snm *.ind *.idx *.bbl *.brf)</translation>
    </message>
</context>
<context>
    <name>ReplaceDialog</name>
    <message>
        <source>Replace</source>
        <translation>Sostituisci</translation>
    </message>
    <message>
        <source>Replace All</source>
        <translation>Sostituisci tutto</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>(invalid)</source>
        <translation>(invalido)</translation>
    </message>
    <message>
        <source>Replace:</source>
        <translation>Sostituisci:</translation>
    </message>
    <message>
        <source>With:</source>
        <translation>Con:</translation>
    </message>
    <message>
        <source>&amp;Wrap around</source>
        <translation>Riparti &amp;dall&apos;inizio</translation>
    </message>
    <message>
        <source>Find &amp;backwards</source>
        <translation>Cerca  &amp;precedente</translation>
    </message>
    <message>
        <source>Replace within &amp;selection</source>
        <translation>Sostituisci dentro la &amp;selezione</translation>
    </message>
    <message>
        <source>Replace in all &amp;open files</source>
        <translation>S&amp;ostituisci dentro tutti i file aperti</translation>
    </message>
    <message>
        <source>&amp;Case sensitive</source>
        <translation>Maius&amp;cole/minuscole</translation>
    </message>
    <message>
        <source>W&amp;hole words</source>
        <translation>Parola int&amp;era</translation>
    </message>
    <message>
        <source>&amp;Regular expression</source>
        <translation>Espressione &amp;regolare</translation>
    </message>
    <message>
        <source>No recent search strings</source>
        <translation>Nessuna ricerca recente</translation>
    </message>
    <message>
        <source>No recent replacement strings</source>
        <translation>Nessuna stringa di sostituzione recente</translation>
    </message>
</context>
<context>
    <name>ResourcesDialog</name>
    <message>
        <source>TeXworks Settings and Resources</source>
        <translation>TeXworks Preferenze e Risorse</translation>
    </message>
    <message>
        <source>Storage Locations</source>
        <translation>Posizioni di salvataggio</translation>
    </message>
    <message>
        <source>Settings:</source>
        <translation>Preferenze:</translation>
    </message>
    <message>
        <source>Resources:</source>
        <translation>Risorse:</translation>
    </message>
    <message>
        <source>Registry (%1)</source>
        <translation>Resistro (%1)</translation>
    </message>
</context>
<context>
    <name>ScreenCalibrationWidget</name>
    <message>
        <source>Drag the ruler or change the value to match real world lengths.
Common paper sizes are marked as well (you may need to resize the dialog window to see them).
Use the context menu to change the units.</source>
        <translation>Trascina il righello o cambia il valore per adeguarlo alla lunghezza reale.
I formati di carta più comunu sono contrassegnati (potresti dover ridimensionare la finestra per riuscire a vederli).
Usa il menù constestuale per cambiare le unità.</translation>
    </message>
    <message>
        <source> dpi</source>
        <extracomment>dots per inch</extracomment>
        <translation>dpi (punti pp)</translation>
    </message>
    <message>
        <source>DIN A4</source>
        <translation>DIN A4</translation>
    </message>
    <message>
        <source>Letter</source>
        <translation>Letter</translation>
    </message>
    <message>
        <source>cm</source>
        <extracomment>this refers to the length unit of centimeters</extracomment>
        <translation>cm</translation>
    </message>
    <message>
        <source>in</source>
        <extracomment>this refers to the length unit of inches</extracomment>
        <translation>pollici</translation>
    </message>
</context>
<context>
    <name>ScriptManager</name>
    <message>
        <source>Manage Scripts</source>
        <translation>Gestisci script</translation>
    </message>
    <message>
        <source>Standalone Scripts</source>
        <translation>Script autonomi</translation>
    </message>
    <message>
        <source>Hook Scripts</source>
        <translation>Hook Script</translation>
    </message>
    <message>
        <source>Name: </source>
        <translation>Nome:</translation>
    </message>
    <message>
        <source>Context: </source>
        <translation>Contesto:</translation>
    </message>
    <message>
        <source>Description: </source>
        <translation>Descrizione:</translation>
    </message>
    <message>
        <source>Author: </source>
        <translation>Autore:</translation>
    </message>
    <message>
        <source>Version: </source>
        <translation>Versione:</translation>
    </message>
    <message>
        <source>Shortcut: </source>
        <translation>Scorciatoia:</translation>
    </message>
    <message>
        <source>File: </source>
        <translation>File:</translation>
    </message>
    <message>
        <source>Language: </source>
        <translation>Linguaggio:</translation>
    </message>
    <message>
        <source>Hook: </source>
        <translation>Hook:</translation>
    </message>
</context>
<context>
    <name>SearchResults</name>
    <message>
        <source>File</source>
        <translation>File</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linea</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Inizio</translation>
    </message>
    <message>
        <source>End</source>
        <translation>Fine</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Testo</translation>
    </message>
    <message>
        <source>Search Results</source>
        <translation>Risultati della ricerca</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Search Results - %1 (%2 found)</source>
        <translation>Risultati della ricerca - %1 (%2 trovato)</translation>
    </message>
</context>
<context>
    <name>TWApp</name>
    <message>
        <source>File</source>
        <translation>File</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nuovo</translation>
    </message>
    <message>
        <source>New from Template...</source>
        <translation>Nuovo da modello...</translation>
    </message>
    <message>
        <source>Preferences...</source>
        <translation>Preferenze...</translation>
    </message>
    <message>
        <source>Open...</source>
        <translation>Apri...</translation>
    </message>
    <message>
        <source>Open Recent</source>
        <translation>Aperti di recente</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Aiuto</translation>
    </message>
    <message>
        <source>About </source>
        <translation>A proposito</translation>
    </message>
    <message>
        <source>Go to TeXworks home page</source>
        <translation>Vai alla home page di Texworks</translation>
    </message>
    <message>
        <source>Email to the mailing list</source>
        <translation>Scrivi alla mailing list</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation>A proposito de %1</translation>
    </message>
    <message>
        <source>Unable to access &quot;%1&quot;; perhaps your browser or mail application is not properly configured?</source>
        <translation>Impossibile accedere a &quot;%1&quot;; forse il tuo browser o il tuo programma di posta non sono configurati correttamente?</translation>
    </message>
    <message>
        <source>Unable to create window</source>
        <translation>Impossibile creare la finestra</translation>
    </message>
    <message>
        <source>Something is badly wrong; %1 was unable to create a document window. The application will now quit.</source>
        <translation>Qualcosa non va; %1 non è riuscito a creare una finestra documento. L&apos;applicazione si chiuderà.</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Apri file</translation>
    </message>
    <message>
        <source>No default binary directory found</source>
        <translation>Directory programmi non trovata</translation>
    </message>
    <message>
        <source>None of the predefined directories for TeX-related programs could be found.&lt;p&gt;&lt;small&gt;To run any processes, you will need to set the binaries directory (or directories) for your TeX distribution using the Typesetting tab of the Preferences dialog.&lt;/small&gt;</source>
        <translation>Non è stato possibile trovare nessuna delle directory predefinite per i programmi relativi a Tex.&lt;p&gt;&lt;small&gt;Per lanciare qualsiasi processo devi definire la(e) directory dove risiede la tua distribuzione Tex utilizzando la scheda Typesetting delle Preferenze.&lt;/small&gt;</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation></translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation></translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation></translation>
    </message>
    <message>
        <source>&lt;p&gt;%1 is a simple environment for editing, typesetting, and previewing TeX documents.&lt;/p&gt;</source>
        <translation>&lt;p&gt;%1 è un semplice ambiente per la modifica, la composizione e l&apos;anteprima di documenti TeX&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;br&gt;&lt;a href=&quot;http://poppler.freedesktop.org/&quot;&gt;Poppler&lt;/a&gt; PDF rendering library by Kristian H&amp;#xF8;gsberg, Albert Astals Cid and others.</source>
        <translation>&lt;br&gt;&lt;a href=&quot;http://poppler.freedesktop.org/&quot;&gt;Poppler&lt;/a&gt; PDF rendering library by Kristian H&amp;#xF8;gsberg, Albert Astals Cid and others.</translation>
    </message>
    <message>
        <source>&lt;br&gt;Concept and resources from &lt;a href=&quot;http://www.uoregon.edu/~koch/texshop/&quot;&gt;TeXShop&lt;/a&gt; by Richard Koch.</source>
        <translation>&lt;br&gt;Concept and resources from &lt;a href=&quot;http://www.uoregon.edu/~koch/texshop/&quot;&gt;TeXShop&lt;/a&gt; by Richard Koch.</translation>
    </message>
    <message>
        <source>&lt;br&gt;&lt;a href=&quot;http://itexmac.sourceforge.net/SyncTeX.html&quot;&gt;SyncTeX&lt;/a&gt; technology by J&amp;#xE9;r&amp;#xF4;me Laurens.</source>
        <translation>&lt;br&gt;&lt;a href=&quot;http://itexmac.sourceforge.net/SyncTeX.html&quot;&gt;SyncTeX&lt;/a&gt; technology by J&amp;#xE9;r&amp;#xF4;me Laurens.</translation>
    </message>
    <message>
        <source>&lt;br&gt;Some icons used are from the &lt;a href=&quot;http://tango.freedesktop.org/&quot;&gt;Tango Desktop Project&lt;/a&gt;.</source>
        <translation>&lt;br&gt;Some icons used are from the &lt;a href=&quot;http://tango.freedesktop.org/&quot;&gt;Tango Desktop Project&lt;/a&gt;.</translation>
    </message>
    <message>
        <source>&lt;p&gt;%1 translation kindly contributed by %2.</source>
        <translation>&lt;p&gt;Traduzione %1 a cura di  %2.</translation>
    </message>
    <message>
        <source>[language name]</source>
        <translation>Italiana</translation>
    </message>
    <message>
        <source>[translator&apos;s name/email]</source>
        <translation>trebestie@gmail.com</translation>
    </message>
    <message>
        <source>Unable to find help file.</source>
        <translation>Guida non disponibile.</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>Salva file</translation>
    </message>
    <message>
        <source>Permission request</source>
        <translation>Richiesta permesso</translation>
    </message>
    <message>
        <source>The script &quot;%1&quot; is trying to open the file &quot;%2&quot; without sufficient permissions. Do you want to open the file?</source>
        <translation>Lo script &quot;%1&quot; sta cercando di aprire il file &quot;%2&quot; senza sufficienti permessi. Vuoi aprire il file?</translation>
    </message>
    <message>
        <source>&lt;p&gt;Distributed under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl-2.0.html&quot;&gt;GNU General Public License&lt;/a&gt;, version 2 or (at your option) any later version.</source>
        <translation>&lt;p&gt;Distribuito sotto la &lt;a href=&quot;http://www.gnu.org/licenses/gpl-2.0.html&quot;&gt;GNU General Public License&lt;/a&gt;, versione 2 o (a vostra opzione) successive.</translation>
    </message>
    <message>
        <source>Clear Recent Files</source>
        <translation>Elimina file recenti</translation>
    </message>
    <message>
        <source>&lt;br&gt;Version %1 (%2) [r.%3, %4]</source>
        <translation>&lt;br&gt;Versione %1 (%2) [r.%3, %4]</translation>
    </message>
    <message>
        <source>&lt;br&gt;Version %1 (%2)</source>
        <translation>&lt;br&gt;Version %1 (%2)</translation>
    </message>
    <message>
        <source>Quit TeXworks</source>
        <translation>Lascia TeXworks</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;a href=&quot;http://www.qt.io/&quot;&gt;Qt application framework&lt;/a&gt; v%1 by The Qt Company.</source>
        <translation>&lt;p&gt;&lt;a href=&quot;http://www.qt.io/&quot;&gt;Qt application framework&lt;/a&gt; v%1 della The Qt Company.</translation>
    </message>
    <message>
        <source>&lt;br&gt;&lt;a href=&quot;http://hunspell.github.io/&quot;&gt;Hunspell&lt;/a&gt; spell checker by L&amp;#xE1;szl&amp;#xF3; N&amp;#xE9;meth.</source>
        <translation>&lt;br&gt;&lt;a href=&quot;http://hunspell.github.io/&quot;&gt;Hunspell&lt;/a&gt; correttore ortografico a cura di L&amp;#xE1;szl&amp;#xF3; N&amp;#xE9;meth.</translation>
    </message>
</context>
<context>
    <name>TWScriptAPI</name>
    <message>
        <source>Internal error</source>
        <translation>Errore interno</translation>
    </message>
    <message>
        <source>Failed to execute system command: %1</source>
        <translation>Tentativo fallito di esecuzione del comando: %1</translation>
    </message>
    <message>
        <source>Error executing system command: %1</source>
        <translation>Errore nell&apos;esecuzione del comando: %1</translation>
    </message>
    <message>
        <source>System command execution is disabled (see Preferences)</source>
        <translation>Esecuzione dei comandi di sistema disabilitata (vedi Preferenze)</translation>
    </message>
    <message>
        <source>&quot;%1&quot; could not be opened.</source>
        <translation>&quot;%1&quot; non può essere aperto.</translation>
    </message>
    <message>
        <source>Reading all files is disabled (see Preferences)</source>
        <translation>Lettura di tutti i file disabilitata (vedi Preferenze)</translation>
    </message>
    <message>
        <source>The file &quot;%1&quot; could not be opened for reading</source>
        <translation>Il file &quot;%1&quot; non può essere aperto per la lettura</translation>
    </message>
</context>
<context>
    <name>TWScriptable</name>
    <message>
        <source>Script &quot;%1&quot;: %2</source>
        <translation>Script &quot;%1&quot;: %2</translation>
    </message>
    <message>
        <source>Script result</source>
        <translation>Risultato dello script</translation>
    </message>
    <message>
        <source>unknown error</source>
        <translation>errore sconosciuto</translation>
    </message>
    <message>
        <source>Scripts may be used to add new commands to %1, and to extend or modify its behavior.</source>
        <translation>Gli script possono essere usati per aggiungere nuovi comandi a %1, o estendere o modificare il loro comportamento.</translation>
    </message>
    <message>
        <source>For more information on creating and using scripts, see %1&lt;/p&gt;</source>
        <translation>Per maggiori informazioni su creazione e uso degli script consulta %1&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Scripting languages currently available in this copy of %1:</source>
        <translation>Linguaggi di scripting attualmente disponibili in questa copia di %1:</translation>
    </message>
    <message>
        <source>About Scripts</source>
        <translation>A proposito degli script</translation>
    </message>
    <message>
        <source>Script error</source>
        <translation>Errore nello script</translation>
    </message>
    <message>
        <source>(disabled in the preferences)</source>
        <extracomment>This string is appended to a script language name to indicate it is currently disabled</extracomment>
        <translation>(disabilitato nelle preferenze)</translation>
    </message>
</context>
<context>
    <name>TWSystemCmd</name>
    <message>
        <source>ERROR: failure code %1</source>
        <translation>ERRORE: codice %1</translation>
    </message>
    <message>
        <source>ERROR: exit code %1</source>
        <translation>ERRORE: codice uscita %1</translation>
    </message>
</context>
<context>
    <name>TagsDock</name>
    <message>
        <source>Tags</source>
        <translation>Tag</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Segnalibri</translation>
    </message>
    <message>
        <source>Outline</source>
        <translation>Struttura</translation>
    </message>
    <message>
        <source>No tags</source>
        <translation>Nessun tag</translation>
    </message>
</context>
<context>
    <name>TeXDocument</name>
    <message>
        <source>New document</source>
        <translation>Nuovo documento</translation>
    </message>
    <message>
        <source>Open Recent</source>
        <translation>Apri recenti</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nessuno</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Apri File</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>Salva file</translation>
    </message>
    <message>
        <source>The document &quot;%1&quot; has been modified.
Do you want to save your changes?</source>
        <translation>Il documento &quot;%1&quot; è stato modificato.
Vuoi salvare i cambiamenti?</translation>
    </message>
    <message>
        <source>Do you want to discard all changes to the document &quot;%1&quot;, and revert to the last saved version?</source>
        <translation>Vuoi annullare tutte le modifiche al documento &quot;%1&quot;, e ripristinare l&apos;ultima versione salvata?</translation>
    </message>
    <message>
        <source>Revert</source>
        <translation>Ripristina</translation>
    </message>
    <message>
        <source>Unrecognized encoding</source>
        <translation>Encoding sconosciuto</translation>
    </message>
    <message>
        <source>The text encoding %1 used in %2 is not supported.

It will be interpreted as %3 instead, which may result in incorrect text.</source>
        <translation>L&apos;encoding del testo %1 utilizzato in %2 non è supportato.

Sarà interpretato invece come %3 e potresti ottenere un testo non corretto.</translation>
    </message>
    <message>
        <source>Text cannot be converted</source>
        <translation>Il testo non può essere convertito</translation>
    </message>
    <message>
        <source>This document contains characters that cannot be represented in the encoding %1.

If you proceed, they will be replaced with default codes. Alternatively, you may wish to use a different encoding (such as UTF-8) to avoid loss of data.</source>
        <translation>Questo documento contiene caratteri che non possono essere visualizzati nell&apos;encoding %1.

Se continui saranno sostituiti da caratteri di default. In alternativa puoi cambiare tipo di encoding (es. UTF-8) per evitare la perdita di dati.</translation>
    </message>
    <message>
        <source>Document &quot;%1&quot; was not saved</source>
        <translation>Il documento &quot;%1&quot; non è stato salvato</translation>
    </message>
    <message>
        <source>untitled-%1.tex</source>
        <translation>senza-nome-%1.tex</translation>
    </message>
    <message>
        <source>%1[*] - %2</source>
        <translation>%1[*] - %2</translation>
    </message>
    <message>
        <source>Line %1 of %2; col %3</source>
        <translation>Linea %1 di %2 ; col %3</translation>
    </message>
    <message>
        <source>Go to Line</source>
        <translation>Andare alla linea</translation>
    </message>
    <message>
        <source>Line number:</source>
        <translation>Linea numero :</translation>
    </message>
    <message>
        <source>Invalid regular expression</source>
        <translation>Espressione regolare non corretta</translation>
    </message>
    <message>
        <source>Not found</source>
        <translation>Non trovato</translation>
    </message>
    <message>
        <source>Cannot process unsaved document</source>
        <translation>Impossibile procedere su un documento non salvato</translation>
    </message>
    <message>
        <source>%1 is not properly configured</source>
        <translation>%1 non è configurato correttamente</translation>
    </message>
    <message>
        <source>Unable to execute %1</source>
        <translation>Impossibile eseguire %1</translation>
    </message>
    <message>
        <source>Set engine to &quot;%1&quot;</source>
        <translation>Formato da usare &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Engine &quot;%1&quot; not defined</source>
        <translation>Formato &quot;%1&quot; non definito</translation>
    </message>
    <message>
        <source>untitled.tex[*]</source>
        <translation>senza-nome.tex[*]</translation>
    </message>
    <message>
        <source>File</source>
        <translation>File</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Modifica</translation>
    </message>
    <message>
        <source>Spelling</source>
        <translation>Verifica ortografica</translation>
    </message>
    <message>
        <source>Change Case</source>
        <translation>Cambia Maiuscole/minuscole</translation>
    </message>
    <message>
        <source>Typeset</source>
        <translation>Composizione</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Finestra</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>Visualizza</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <source>Auto-indent Mode</source>
        <translation>Rientro automatico</translation>
    </message>
    <message>
        <source>Syntax Coloring</source>
        <translation>Colorazione sintassi</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Aiuto</translation>
    </message>
    <message>
        <source>Typeset Toolbar</source>
        <translation>Pulsanti barra strumenti Composizione</translation>
    </message>
    <message>
        <source>Edit Toolbar</source>
        <translation>Barra strumenti Modifica</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nuovo</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation></translation>
    </message>
    <message>
        <source>Open...</source>
        <translation>Apri...</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation></translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation></translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Salva</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation></translation>
    </message>
    <message>
        <source>Save As...</source>
        <translation>Salva come...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+S</source>
        <translation></translation>
    </message>
    <message>
        <source>Revert to Saved</source>
        <translation>Ritorna alla versione salvata</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation></translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Ripeti</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Z</source>
        <translation></translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Taglia</translation>
    </message>
    <message>
        <source>Ctrl+X</source>
        <translation></translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <source>Ctrl+C</source>
        <translation></translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Incolla</translation>
    </message>
    <message>
        <source>Ctrl+V</source>
        <translation></translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Pulisci</translation>
    </message>
    <message>
        <source>Find...</source>
        <translation>Cerca...</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation></translation>
    </message>
    <message>
        <source>Find Again</source>
        <translation>Cerca successivo</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation></translation>
    </message>
    <message>
        <source>Replace...</source>
        <translation>Sostituisci...</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation></translation>
    </message>
    <message>
        <source>Copy to Find</source>
        <translation>Copia in Cerca</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation></translation>
    </message>
    <message>
        <source>Copy to Replace</source>
        <translation>Copia in Sostituisci</translation>
    </message>
    <message>
        <source>Ctrl+Shift+E</source>
        <translation></translation>
    </message>
    <message>
        <source>Go to Line...</source>
        <translation>Andare alla linea...</translation>
    </message>
    <message>
        <source>Ctrl+L</source>
        <translation></translation>
    </message>
    <message>
        <source>Find Selection</source>
        <translation>Trova selezione</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation></translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Seleziona tutto</translation>
    </message>
    <message>
        <source>Ctrl+A</source>
        <translation></translation>
    </message>
    <message>
        <source>Font...</source>
        <translation>Carattere...</translation>
    </message>
    <message>
        <source>Indent</source>
        <translation>Rientra</translation>
    </message>
    <message>
        <source>Ctrl+]</source>
        <translation>Ctrl+]</translation>
    </message>
    <message>
        <source>Unindent</source>
        <translation>Elimina rientro</translation>
    </message>
    <message>
        <source>Ctrl+[</source>
        <translation>Ctrl+[</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Commenta</translation>
    </message>
    <message>
        <source>Ctrl+Shift+]</source>
        <translation></translation>
    </message>
    <message>
        <source>Uncomment</source>
        <translation>De-commenta</translation>
    </message>
    <message>
        <source>Ctrl+Shift+[</source>
        <translation></translation>
    </message>
    <message>
        <source>Wrap Lines</source>
        <translation>A capo automatico</translation>
    </message>
    <message>
        <source>About TeXworks...</source>
        <translation>A proposito di TeXworks...</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Cascata</translation>
    </message>
    <message>
        <source>Tile</source>
        <translation>Mosaico</translation>
    </message>
    <message>
        <source>Preferences...</source>
        <translation>Preferenze...</translation>
    </message>
    <message>
        <source>Go to Preview</source>
        <translation>Vai all&apos;anteprima</translation>
    </message>
    <message>
        <source>Ctrl+&apos;</source>
        <translation></translation>
    </message>
    <message>
        <source>Ctrl+\</source>
        <translation></translation>
    </message>
    <message>
        <source>New from Template...</source>
        <translation>Nuovo da modello...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation></translation>
    </message>
    <message>
        <source>Show Selection</source>
        <translation>Mostra Selezione</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation></translation>
    </message>
    <message>
        <source>ALL UPPERCASE</source>
        <translation>TUTTO MAIUSCOLO</translation>
    </message>
    <message>
        <source>all lowercase</source>
        <translation>tutto minuscolo</translation>
    </message>
    <message>
        <source>Balance Delimiters</source>
        <translation>Corrispondenza parentesi</translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation></translation>
    </message>
    <message>
        <source>Go to TeXworks home page</source>
        <translation>Vai alla home page di Texworks</translation>
    </message>
    <message>
        <source>Email to the mailing list</source>
        <translation>Scrivi alla mailing list</translation>
    </message>
    <message>
        <source>Side by Side</source>
        <translation>Affiancate</translation>
    </message>
    <message>
        <source>Place on Left</source>
        <translation>Metti a sinistra</translation>
    </message>
    <message>
        <source>Place on Right</source>
        <translation>Metti a destra</translation>
    </message>
    <message>
        <source>File changed on disk</source>
        <translation>File modificato sul disco</translation>
    </message>
    <message>
        <source>%1 has been modified by another program.

Do you want to discard your current changes, and reload the file from disk?</source>
        <translation>%1 è stato modificato da un altro programma.

Vuoi annullare le modifiche e ricaricare il file dal disco?</translation>
    </message>
    <message>
        <source>%1 has been modified by another program.

Do you want to proceed with saving this file, overwriting the version on disk?</source>
        <translation>%1 è stato modificato da un altro programma.

Vuoi salvare le modifiche e sovrascrivere il file sul disco?</translation>
    </message>
    <message numerus="yes">
        <source>Found %n occurrence(s)</source>
        <translation>
            <numerusform>trovata %n occorrenza</numerusform>
            <numerusform>trovate %n occorrenze</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n occurrence(s)</source>
        <translation>
            <numerusform>%n occorrenza        </numerusform>
            <numerusform>%n occorrenze</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n documents</source>
        <translation>
            <numerusform>%n documento        </numerusform>
            <numerusform>%n documenti</numerusform>
        </translation>
    </message>
    <message>
        <source>Replaced %1 in %2</source>
        <translation>%1 sostituito con  %2</translation>
    </message>
    <message numerus="yes">
        <source>Replaced %n occurrence(s)</source>
        <translation>
            <numerusform>Effettuata %n sostituzione        </numerusform>
            <numerusform>Effettuate %n sostituzioni        </numerusform>
        </translation>
    </message>
    <message>
        <source>Root document %1 is not readable</source>
        <translation>Il documento root %1 non è leggibile</translation>
    </message>
    <message>
        <source>No files found</source>
        <translation>Nessun file trovato</translation>
    </message>
    <message>
        <source>No auxiliary files associated with this document at the moment.</source>
        <translation>Nessun file ausiliario associato a questo documento per ora.</translation>
    </message>
    <message>
        <source>Replace Again</source>
        <translation>Sostituisci ancora</translation>
    </message>
    <message>
        <source>Ctrl+Shift+R</source>
        <translation></translation>
    </message>
    <message>
        <source>Remove Aux Files...</source>
        <translation>Eliminare i file ausiliari...</translation>
    </message>
    <message>
        <source>Quit TeXworks</source>
        <translation>Esci da TeXworks</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation></translation>
    </message>
    <message>
        <source>Smart Quotes</source>
        <translation>Virgolette</translation>
    </message>
    <message>
        <source>Toggle Case</source>
        <translation>Scambia MAIUSCOLE/minuscole</translation>
    </message>
    <message>
        <source>The program &quot;%1&quot; was not found.</source>
        <translation>Il programma &quot;%1&quot; non è stato trovato.</translation>
    </message>
    <message>
        <source>Searched in directories:</source>
        <translation>Cercato nelle directory:</translation>
    </message>
    <message>
        <source>Typeset</source>
        <comment>menu title</comment>
        <translation>Composizione</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <comment>action</comment>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Hard Wrap...</source>
        <translation>A capo...</translation>
    </message>
    <message>
        <source>Line Numbers</source>
        <translation>Numeri di linea</translation>
    </message>
    <message>
        <source>Process interrupted by user</source>
        <translation>Processo interrotto dall&apos;utente</translation>
    </message>
    <message>
        <source>Console output</source>
        <translation>Console di output</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>Script</translation>
    </message>
    <message>
        <source>Scripting TeXworks</source>
        <translation>TeXworks scripting</translation>
    </message>
    <message>
        <source>Show Scripts Folder</source>
        <translation>Mostra cartella script</translation>
    </message>
    <message>
        <source>Reload Script List</source>
        <translation>Ricarica lista script</translation>
    </message>
    <message>
        <source>Manage Scripts</source>
        <translation>Gestisci script</translation>
    </message>
    <message>
        <source>Auto-Follow Focus</source>
        <translation>Segui automaticamente il focus</translation>
    </message>
    <message>
        <source>About Scripts...</source>
        <translation>A proposito degli script...</translation>
    </message>
    <message>
        <source>Apply to Selection</source>
        <translation>Applica alla selezione</translation>
    </message>
    <message>
        <source>Save All</source>
        <translation>Salva tutto</translation>
    </message>
    <message>
        <source>Ctrl+Alt+S</source>
        <translation>Ctrl+Alt+S</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <comment>shortcut: Don&apos;t Save</comment>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <comment>shortcut: Revert</comment>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Cannot read file &quot;%1&quot;:
%2</source>
        <translation>Impossibile leggere il file &quot;%1&quot;
%2</translation>
    </message>
    <message>
        <source>File &quot;%1&quot; loaded</source>
        <translation>Filer &quot;%1&quot; caricato</translation>
    </message>
    <message>
        <source>%1 is constantly being modified by another program.

Please use &quot;File &gt; Revert to Saved&quot; manually when the external process has finished.</source>
        <translation>%1 è in corso di modifica da un altro programma.

Usa &quot;File &gt; Ritorna alla copia salvata&quot; manualmente quando il processo esterno è terminato.</translation>
    </message>
    <message>
        <source>Cannot write file &quot;%1&quot;:
%2</source>
        <translation>Impossibile scrivere il file &quot;%1&quot;:
%2</translation>
    </message>
    <message>
        <source>Error writing file</source>
        <translation>Errore nella scrittura del file</translation>
    </message>
    <message>
        <source>An error may have occurred while saving the file. You might like to save a copy in a different location.</source>
        <translation>Si è verificato un errore durante il salvataggio del file. Forse dovresti salvare una copia in una posizione differente.</translation>
    </message>
    <message>
        <source>File &quot;%1&quot; saved</source>
        <translation>File &quot;%1&quot; salvato</translation>
    </message>
    <message>
        <source>Abort typesetting</source>
        <translation>Interrompi composizione</translation>
    </message>
    <message>
        <source>Settings and Resources...</source>
        <translation>Preferenze e Risorse...</translation>
    </message>
    <message>
        <source>Reload using selected encoding</source>
        <extracomment>Item in the encoding popup menu</extracomment>
        <translation>Ricarica usando l&apos;encoding scelto</translation>
    </message>
    <message>
        <source>Reloads the current file with the encoding selected from this menu.

The selected encoding replaces the default one and overrides all &quot;%!TEX encoding&quot; lines.</source>
        <extracomment>Tooltip for &quot;Reload using selected encoding&quot;</extracomment>
        <translation>Ricarica il file corrente con l&apos;encoding scelto da questo menù.

L&apos;encoding scelto sostituisce quello di default e sovrascrive tutte le linee &quot;%!TEX encoding&quot;.</translation>
    </message>
    <message>
        <source>Unsaved changes</source>
        <translation>Cambiamenti non salvati</translation>
    </message>
    <message>
        <source>The file you are trying to reload has unsaved changes.

Do you want to discard your current changes, and reload the file from disk with the encoding %1?</source>
        <translation>Il file che stai cercando di ricaricare contiene modifiche non salvate.

Vuoi abbandonare le modifiche correnti e ricaricare il file dal disco usando l&apos;encoding %1?</translation>
    </message>
    <message>
        <source>Clear Recent Files</source>
        <translation>Eliminare i file recenti</translation>
    </message>
    <message>
        <source>Abort typesetting?</source>
        <translation>Interrompi composizione?</translation>
    </message>
    <message>
        <source>A typesetting process is still running and must be stopped before closing this window.
Do you want to stop it now?</source>
        <translation>E&apos; in corso un processo di compisizione e dovrà essere interrotto prima di chiudere questa finestra.
Sei sicuro di voler interrompere adesso?</translation>
    </message>
    <message>
        <source>You need a &lt;b&gt;TeX distribution&lt;/b&gt; like &lt;a href=&quot;http://tug.org/texlive/&quot;&gt;TeX Live&lt;/a&gt; or &lt;a href=&quot;http://miktex.org/&quot;&gt;MiKTeX&lt;/a&gt; installed on your system to typeset your document.</source>
        <translation>Occorre una &lt;b&gt;distribuzione TeX&lt;/b&gt; come &lt;a href=&quot;http://tug.org/texlive/&quot;&gt;TeX Live&lt;/a&gt; or &lt;a href=&quot;http://miktex.org/&quot;&gt;MiKTeX&lt;/a&gt; installata sul tuo sistema per avviare la composizione del documento.</translation>
    </message>
    <message>
        <source>You need a &lt;b&gt;TeX distribution&lt;/b&gt; like &lt;a href=&quot;http://www.tug.org/mactex/&quot;&gt;MacTeX&lt;/a&gt; installed on your system to typeset your document.</source>
        <translation>Occorre una &lt;b&gt;distribuzione TeX&lt;/b&gt; come &lt;a href=&quot;http://www.tug.org/mactex/&quot;&gt;MacTeX&lt;/a&gt; installata sul tuo sistema per avviare la composizione del documento.</translation>
    </message>
    <message>
        <source>You need a &lt;b&gt;TeX distribution&lt;/b&gt; like &lt;a href=&quot;http://tug.org/texlive/&quot;&gt;TeX Live&lt;/a&gt; installed on your system to typeset your document. On most systems such a TeX distribution is available as prebuilt package.</source>
        <translation>Occorre una &lt;b&gt;distribuzione TeX&lt;/b&gt; come &lt;a &lt;a href=&quot;http://tug.org/texlive/&quot;&gt;TeX Live&lt;/a&gt;&gt; installata sul tuo sistema per avviare la composizione del documento. In molti sistemi una distribuzione TeX è disponibile come pacchetto precompilato.</translation>
    </message>
    <message>
        <source>When a TeX distribution is installed you may need to tell TeXworks where to find it in Edit -&gt; Preferences -&gt; Typesetting.</source>
        <translation>Quando una ditribuzione TeX è installata nel sistema devi dire a TeXworks dove trovarla in Modifica -&gt; Preferenze -&gt; Composizione.</translation>
    </message>
    <message>
        <source>Check the configuration of the %1 tool and the path settings in the Preferences dialog.</source>
        <translation>Controlla configurazione e percorso del programma %1 nella finestra di dialogo Preferenze. </translation>
    </message>
    <message>
        <source>Hide Console Output</source>
        <translation>Nascondi il pannello di output</translation>
    </message>
    <message>
        <source>Layout Problem</source>
        <translation>Problema di layout</translation>
    </message>
    <message>
        <source>A problem occured while laying out the loaded document in the editor. This is caused by an issue in the underlying Qt framework and can cause TeXworks to crash under certain circumstances. The symptoms of this problem are hidden or overlapping lines. To work around this, please try one of the following:
 -) Turn syntax highlighting off and on
 -) Turn line numbers off and on
 -) Resize the window

We are sorry for the inconvenience.</source>
        <translation>Errore durante la disposizione del documento nell&apos;editor. Questo è causato da un problema del framework Qt e in qualche caso può causare il crash di TeXworks. I sintomi di questo errore sono righe nascoste o sovrapposte. Per cercare di risolvere prova a:
 -) attivare/disattivare l&apos;evidenziazione della sintassi
 -) attivare/disattivare i numeri di riga
 -) ridimensionare la finestra

Ci dispiace per l&apos;inconveniente.</translation>
    </message>
    <message>
        <source>Show Console Output</source>
        <translation>Mostra il pannello di output</translation>
    </message>
    <message>
        <source>Write UTF-8 byte order mark</source>
        <translation>Scrivi il codice UTF-8 byte order mark (BOM)</translation>
    </message>
</context>
<context>
    <name>TeXHighlighter</name>
    <message>
        <source>default</source>
        <translation>default</translation>
    </message>
</context>
<context>
    <name>TemplateDialog</name>
    <message>
        <source>New File using Template</source>
        <translation>Nuovo da modello</translation>
    </message>
    <message>
        <source>Choose template for the new document:</source>
        <translation>Scegli un modello per il nuovo documento:</translation>
    </message>
</context>
<context>
    <name>ToolConfig</name>
    <message>
        <source>NewArgument</source>
        <translation>Nuovo argomento</translation>
    </message>
    <message>
        <source>Select program file</source>
        <translation>Scegli il file di programma</translation>
    </message>
    <message>
        <source>Invalid program</source>
        <translation>Programma non valido</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; is not executable!</source>
        <translation>Il file &apos;%1&apos; non è eseguibile!</translation>
    </message>
</context>
<context>
    <name>ToolConfigDialog</name>
    <message>
        <source>Tool Configuration</source>
        <translation>Strumento di configurazione</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nome:</translation>
    </message>
    <message>
        <source>Program:</source>
        <translation>Programma:</translation>
    </message>
    <message>
        <source>Arguments:</source>
        <translation>Argomenti:</translation>
    </message>
    <message>
        <source>View PDF after running</source>
        <translation>Visualizza PDF dopo composizione</translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation>Sfoglia...</translation>
    </message>
</context>
</TS>
